/*
 * Copyright (C) 2011-2012 Eiichiro Uchiumi. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 *     
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.eiichiro.monophony.annotation;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * {@code Accepts} qualifies the set of MIME media type specified by HTTP 
 * request header that the invoked Web endpoint can accept.
 * If Web endpoint method is annotated with this annotation, Monophony validates 
 * whether the MIME media type specified by "Content-Type" HTTP request header 
 * is included in the specified list. If the MIME media type specified by HTTP 
 * request header is not included in the specified list, Monophony returns 
 * HTTP 415 ("Unsupported Media Type") to the client.
 * 
 * @author <a href="mailto:eiichiro@eiichiro.org">Eiichiro Uchiumi</a>
 */
@Documented
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.METHOD)
public @interface Accepts {

	/** MIME media types that Web endpoint method can accept. */
	String[] value();
	
}
